/*
 * Constants and types definitions
 */

#ifndef DEFINES_H
#define DEFINES_H

#define DEFAULT_CFGFILE ".wmmailoadrc"

#define MAXSTRLEN 1024

#define WIN_WIDTH  432
#define WIN_HEIGHT 320

typedef struct MailBox
{
        char *entry;
        char *type;
        char *username;
        char *password;
        char *folder;
        struct MailBox *next;
}
MailBox;

#ifndef TRUE
# define TRUE 1
# define FALSE 0
#endif

#define COLS 6


#endif
